##
##  make.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         make
Summary:      The GNU Make
URL:          http://www.gnu.org/software/make/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        CORE
Group:        Building
License:      GPL
Version:      4.4.1
Release:      20230227

#   list of sources
Source0:      http://ftp.gnu.org/gnu/make/make-%{version}.tar.gz
Patch0:       make.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    This is the GNU variant of make(1). The purpose of this utility is
    to determine automatically which pieces of a large program need to
    be recompiled, and issue the commands to recompile them.

%track
    prog make = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/make/
        regex     = make-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    AR="%{l_ar}" \
    MAKE="%{l_make}" \
    CONFIG_SHELL="%{l_bash}" \
    ./configure \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
        --mandir=%{l_prefix}/man \
        --without-libiconv-prefix \
        --without-libintl-prefix \
        --without-guile \
        --disable-nls

    #   build package
    %{l_make} %{l_mflags -O}

%install
    #   install package
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    ( cd $RPM_BUILD_ROOT%{l_prefix}
      ln bin/make bin/gmake
      ln man/man1/make.1 man/man1/gmake.1
    ) || exit $?

    #   strip down installation
    rm -f  $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share
    strip  $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

